==> unit-1.0.25-sources.jar: io/intino/goros/unit/box/ui/displays/items/NewsListItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NewsListItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.news.Post, UnitBox> {
	public _22_6_0335722147 _22_6_0335722147;
	public NewsListItem._22_6_0335722147. Type type;
	public NewsListItem._22_6_0335722147. Title title;
	public NewsListItem._22_6_0335722147. TitleLink titleLink;
	public NewsListItem._22_6_0335722147. Date date;
	public NewsListItem._22_6_0335722147. Body body;

    public NewsListItem(UnitBox box) {
        super(box);
        id("a1226473668");
    }

    @Override
	public void init() {
		super.init();
		if (_22_6_0335722147 == null) _22_6_0335722147 = register(new _22_6_0335722147(box()).<_22_6_0335722147>id("a1305754982").owner(NewsListItem.this));
		if (_22_6_0335722147 != null) type = _22_6_0335722147.type;
		if (_22_6_0335722147 != null) title = _22_6_0335722147.title;
		if (_22_6_0335722147 != null) titleLink = _22_6_0335722147.titleLink;
		if (_22_6_0335722147 != null) date = _22_6_0335722147.date;
		if (_22_6_0335722147 != null) body = _22_6_0335722147.body;
	}

	public class _22_6_0335722147 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NewsListItem._22_6_0335722147. Type type;
		public NewsListItem._22_6_0335722147. Title title;
		public NewsListItem._22_6_0335722147. TitleLink titleLink;
		public NewsListItem._22_6_0335722147. Date date;
		public NewsListItem._22_6_0335722147. Body body;

		public _22_6_0335722147(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new Type(box()).<Type>id("a1261801014").owner(NewsListItem.this));
			if (title == null) title = register(new Title(box()).<Title>id("a460653276").owner(NewsListItem.this));
			if (titleLink == null) titleLink = register(new TitleLink(box()).<TitleLink>id("a_2124130058").owner(NewsListItem.this));
			if (date == null) date = register(new Date(box()).<Date>id("a1261301418").owner(NewsListItem.this));
			if (body == null) body = register(new Body(box()).<Body>id("a1261254814").owner(NewsListItem.this));
		}

		public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Type(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
			public Type textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public Type backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Title(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class TitleLink extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox> implements io.intino.alexandria.ui.displays.components.addressable.Addressed<TitleLink> {

			public TitleLink(UnitBox box) {
				super(box);
				_title("");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				_path("");
			}

			@Override
			public void init() {
				super.init();
			}
			@Override
			public TitleLink address(java.util.function.Function<String, String> addressFromPathResolver) {
			    address(addressFromPathResolver.apply(path()));
			    return this;
			}
		}

		public class Date extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public Date(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}

		public class Body extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Body(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.17-sources.jar: io/intino/goros/unit/box/ui/displays/items/NewsListItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class NewsListItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.news.Post, UnitBox> {
	public _22_6_01515100204 _22_6_01515100204;
	public NewsListItem._22_6_01515100204. Type type;
	public NewsListItem._22_6_01515100204. Title title;
	public NewsListItem._22_6_01515100204. TitleLink titleLink;
	public NewsListItem._22_6_01515100204. Date date;
	public NewsListItem._22_6_01515100204. Body body;

    public NewsListItem(UnitBox box) {
        super(box);
        id("a1226473668");
    }

    @Override
	public void init() {
		super.init();
		if (_22_6_01515100204 == null) _22_6_01515100204 = register(new _22_6_01515100204(box()).<_22_6_01515100204>id("a_1585005319").owner(NewsListItem.this));
		if (_22_6_01515100204 != null) type = _22_6_01515100204.type;
		if (_22_6_01515100204 != null) title = _22_6_01515100204.title;
		if (_22_6_01515100204 != null) titleLink = _22_6_01515100204.titleLink;
		if (_22_6_01515100204 != null) date = _22_6_01515100204.date;
		if (_22_6_01515100204 != null) body = _22_6_01515100204.body;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_22_6_01515100204 != null) _22_6_01515100204.unregister();
	}

	public class _22_6_01515100204 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public NewsListItem._22_6_01515100204. Type type;
		public NewsListItem._22_6_01515100204. Title title;
		public NewsListItem._22_6_01515100204. TitleLink titleLink;
		public NewsListItem._22_6_01515100204. Date date;
		public NewsListItem._22_6_01515100204. Body body;

		public _22_6_01515100204(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (type == null) type = register(new Type(box()).<Type>id("a1261801014").owner(NewsListItem.this));
			if (title == null) title = register(new Title(box()).<Title>id("a460653276").owner(NewsListItem.this));
			if (titleLink == null) titleLink = register(new TitleLink(box()).<TitleLink>id("a_2124130058").owner(NewsListItem.this));
			if (date == null) date = register(new Date(box()).<Date>id("a1261301418").owner(NewsListItem.this));
			if (body == null) body = register(new Body(box()).<Body>id("a1261254814").owner(NewsListItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (type != null) type.unregister();
			if (title != null) title.unregister();
			if (titleLink != null) titleLink.unregister();
			if (date != null) date.unregister();
			if (body != null) body.unregister();
		}

		public class Type extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Type(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
			public Type textColor(String color) {
			    this._textColor(color);
			    this._refreshHighlight();
			    return this;
			}

			public Type backgroundColor(String color) {
			    this._backgroundColor(color);
			    this._refreshHighlight();
			    return this;
			}
		}

		public class Title extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Title(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class TitleLink extends io.intino.alexandria.ui.displays.components.Action<io.intino.alexandria.ui.displays.notifiers.ActionNotifier, UnitBox> implements io.intino.alexandria.ui.displays.components.addressable.Addressed<TitleLink> {

			public TitleLink(UnitBox box) {
				super(box);
				_title("");
				_mode(io.intino.alexandria.ui.displays.components.Actionable.Mode.valueOf("Link"));
				_path("");
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
			@Override
			public TitleLink address(java.util.function.Function<String, String> addressFromPathResolver) {
			    address(addressFromPathResolver.apply(path()));
			    return this;
			}
		}

		public class Date extends io.intino.alexandria.ui.displays.components.Date<io.intino.alexandria.ui.displays.notifiers.DateNotifier, UnitBox>  {

			public Date(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}

		public class Body extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, UnitBox>  {

			public Body(UnitBox box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
